@@ -5,7 +5,7 @@
  http://libquicktime.sourceforge.net
 
  Copyright (C) 2002 Heroine Virtual Ltd.
- Copyright (C) 2002-2010 Members of the libquicktime project.
+ Copyright (C) 2002-2011 Members of the libquicktime project.
 
  This library is free software; you can redistribute it and/or modify it under
  the terms of the GNU Lesser General Public License as published by the Free
@@ -45,6 +45,15 @@ static inline void transfer_RGB565_to_RGB888(unsigned char *(*output), uint16_t
 	(*output) +=3;
 }
 
+static inline void transfer_RGB565_to_RGBA8888(unsigned char *(*output), uint16_t *input)
+{
+        (*output)[0] = RGB16_TO_R_8(*input);
+        (*output)[1] = RGB16_TO_G_8(*input);
+        (*output)[2] = RGB16_TO_B_8(*input);
+        (*output)[3] = 0xff;
+	(*output) +=4;
+}
+
 // *************************** BGR565 -> ************************************
 
 static inline void transfer_BGR565_to_BGR565(uint16_t *(*output), uint16_t *input)
@@ -61,6 +70,15 @@ static inline void transfer_BGR565_to_RGB888(unsigned char *(*output), uint16_t
 	(*output) +=3;
 }
 
+static inline void transfer_BGR565_to_RGBA8888(unsigned char *(*output), uint16_t *input)
+{
+        (*output)[0] = BGR16_TO_R_8(*input);
+        (*output)[1] = BGR16_TO_G_8(*input);
+        (*output)[2] = BGR16_TO_B_8(*input);
+        (*output)[3] = 0xff;
+	(*output) +=4;
+}
+
 // *************************** RGB888 -> ************************************
 
 static inline void transfer_RGB888_to_BGR565(uint16_t *(*output), unsigned char *input)
@@ -407,7 +425,7 @@ static inline void transfer_RGBA8888_to_YUVA16161616(uint16_t *(*output), unsign
 
 
 
-static inline void transfer_RGBA888_to_YUV420P_YUV422P(unsigned char *output_y, 
+static inline void transfer_RGBA8888_to_YUV420P_YUV422P(unsigned char *output_y, 
 	unsigned char *output_u, 
 	unsigned char *output_v, 
 	unsigned char *input,
@@ -427,7 +445,27 @@ static inline void transfer_RGBA888_to_YUV420P_YUV422P(unsigned char *output_y,
 	output_v[output_column / 2] = v;
 }
 
-static inline void transfer_RGBA888_to_YUV444P(unsigned char *output_y, 
+static inline void transfer_RGBA8888_to_YUVJ420P_YUVJ422P(unsigned char *output_y, 
+	unsigned char *output_u, 
+	unsigned char *output_v, 
+	unsigned char *input,
+	int output_column)
+        {
+	int y, u, v, a, r, g, b;
+	
+	a = input[3];
+	r = (input[0] * a)>> 8;
+	g = (input[1] * a)>> 8;
+	b = (input[2] * a)>> 8;
+
+	RGB_24_TO_YUVJ_8(r, g, b, y, u, v);
+
+	output_y[output_column] = y;
+	output_u[output_column / 2] = u;
+	output_v[output_column / 2] = v;
+}
+
+static inline void transfer_RGBA8888_to_YUV444P(unsigned char *output_y, 
 	unsigned char *output_u, 
 	unsigned char *output_v, 
 	unsigned char *input,
@@ -451,7 +489,7 @@ static inline void transfer_RGBA888_to_YUV444P(unsigned char *output_y,
 
 
 
-static inline void transfer_RGBA888_to_YUV422(unsigned char *(*output), 
+static inline void transfer_RGBA8888_to_YUV422(unsigned char *(*output), 
 	unsigned char *input,
 	int j)
 {
@@ -481,7 +519,83 @@ static inline void transfer_RGBA888_to_YUV422(unsigned char *(*output),
 
 }
 
+static inline void transfer_RGBA8888_to_YUV422P16(uint16_t *output_y, 
+	uint16_t *output_u, 
+	uint16_t *output_v, 
+	unsigned char *input,
+	int output_column)
+{
+	int a, r, g, b;
+	
+	a = input[3];
+	r = (input[0] * a)>> 8;
+	g = (input[1] * a)>> 8;
+	b = (input[2] * a)>> 8;
 
+	RGB_24_TO_YUV_16(r, g, b, output_y[output_column], output_u[output_column/2], output_v[output_column/2]);
+
+}
+
+static inline void transfer_RGBA8888_to_YUV411P(unsigned char *output_y, 
+	unsigned char *output_u, 
+	unsigned char *output_v, 
+	unsigned char *input,
+	int output_column)
+{
+        int y, u, v, a, r, g, b;
+	
+	a = input[3];
+	r = (input[0] * a)>> 8;
+	g = (input[1] * a)>> 8;
+	b = (input[2] * a)>> 8;
+
+	RGB_24_TO_YUV_8(r, g, b, y, u, v);
+
+	output_y[output_column] = y;
+	output_u[output_column / 4] = u;
+	output_v[output_column / 4] = v;
+}
+
+
+static inline void transfer_RGBA8888_to_YUVJ444P(unsigned char *output_y, 
+	unsigned char *output_u, 
+	unsigned char *output_v, 
+	unsigned char *input,
+	int output_column)
+{
+        int y, u, v, a, r, g, b;
+	
+	a = input[3];
+	r = (input[0] * a)>> 8;
+	g = (input[1] * a)>> 8;
+	b = (input[2] * a)>> 8;
+
+	RGB_24_TO_YUVJ_8(r, g, b, y, u, v);
+
+	output_y[output_column] = y;
+	output_u[output_column] = u;
+	output_v[output_column] = v;
+}
+
+static inline void transfer_RGBA8888_to_YUV444P16(uint16_t *output_y, 
+                                                uint16_t *output_u, 
+                                                uint16_t *output_v, 
+                                                unsigned char *input,
+                                                int output_column)
+{
+        int y, u, v, a, r, g, b;
+	
+	a = input[3];
+	r = (input[0] * a)>> 8;
+	g = (input[1] * a)>> 8;
+	b = (input[2] * a)>> 8;
+
+	RGB_24_TO_YUV_16(r, g, b, y, u, v);
+
+	output_y[output_column] = y;
+	output_u[output_column] = u;
+	output_v[output_column] = v;
+}
 
 
 
@@ -574,6 +688,33 @@ static inline void transfer_RGB161616_to_YUV420P_YUV422P(unsigned char *output_y
 	output_v[output_column / 2] = v;
 }
 
+static inline void transfer_RGB161616_to_YUV422(unsigned char *(*output),
+  uint16_t *input,
+  int j)
+{
+  int y, u, v, r, g, b;
+  r = input[0];
+  g = input[1];
+  b = input[2];
+
+  RGB_48_TO_YUV_8(r,g,b,y,u,v);
+
+  if(!(j & 1))
+  {
+// Store U and V for even pixels only
+     (*output)[1] = u;
+     (*output)[3] = v;
+     (*output)[0] = y;
+  }
+  else
+  {
+// Store Y and advance output for odd pixels only
+     (*output)[2] = y;
+     (*output) += 4;
+  }
+
+}
+
 static inline void transfer_RGB161616_to_YUV422P16(uint16_t *output_y, 
 	uint16_t *output_u, 
 	uint16_t *output_v, 
@@ -771,6 +912,15 @@ static inline void transfer_BGR8888_to_RGB888(unsigned char *(*output), unsigned
 	(*output) += 3;
 }
 
+static inline void transfer_BGR8888_to_RGBA8888(unsigned char *(*output), unsigned char *input)
+{
+	(*output)[0] = input[2];
+	(*output)[1] = input[1];
+	(*output)[2] = input[0];
+        (*output)[3] = 0xff;
+	(*output) += 4;
+}
+
 static inline void transfer_BGR8888_to_BGR8888(unsigned char *(*output), unsigned char *input)
 {
 	(*output)[0] = input[0];
@@ -1261,6 +1411,17 @@ static inline void transfer_YUV422P16_to_RGB888(unsigned char *(*output),
 	(*output) += 3;
 }
 
+static inline void transfer_YUV422P16_to_RGBA8888(unsigned char *(*output), 
+	uint16_t *input_y,
+	uint16_t *input_u,
+	uint16_t *input_v)
+{
+        int i_tmp;
+	YUV_16_TO_RGB_24(*input_y, *input_u, *input_v, (*output)[0], (*output)[1], (*output)[2])
+        (*output)[3] = 0xff;
+	(*output) += 4;
+}
+
 static inline void transfer_YUV422P16_to_RGB161616(uint16_t *(*output), 
 	uint16_t *input_y,
 	uint16_t *input_u,
@@ -1309,6 +1470,17 @@ static inline void transfer_YUV444P16_to_RGB888(unsigned char *(*output),
 	(*output) += 3;
 }
 
+static inline void transfer_YUV444P16_to_RGBA8888(unsigned char *(*output), 
+	uint16_t *input_y,
+	uint16_t *input_u,
+	uint16_t *input_v)
+{
+        int i_tmp;
+	YUV_16_TO_RGB_24(*input_y, *input_u, *input_v, (*output)[0], (*output)[1], (*output)[2])
+        (*output)[3] = 0xff;
+	(*output) += 4;
+}
+
 static inline void transfer_YUV444P16_to_RGB161616(uint16_t *(*output), 
 	uint16_t *input_y,
 	uint16_t *input_u,
@@ -1358,6 +1530,17 @@ static inline void transfer_YUV411P_to_RGB888(unsigned char *(*output),
 	(*output) += 3;
 }
 
+static inline void transfer_YUV411P_to_RGBA8888(unsigned char *(*output), 
+	unsigned char *input_y,
+	unsigned char *input_u,
+	unsigned char *input_v)
+{
+        int i_tmp;
+	YUV_8_TO_RGB_24(*input_y, *input_u, *input_v, (*output)[0], (*output)[1], (*output)[2])
+        (*output)[3] = 0xff;
+	(*output) += 4;
+}
+
 
 // ******************************** YUV444P -> ********************************
 
@@ -1386,6 +1569,17 @@ static inline void transfer_YUVJ444P_to_RGB888(unsigned char *(*output),
 	(*output) += 3;
 }
 
+static inline void transfer_YUVJ444P_to_RGBA8888(unsigned char *(*output), 
+	unsigned char *input_y,
+	unsigned char *input_u,
+	unsigned char *input_v)
+{
+        int i_tmp;
+	YUVJ_8_TO_RGB_24(*input_y, *input_u, *input_v, (*output)[0], (*output)[1], (*output)[2])
+        (*output)[3] = 0xff;
+	(*output) += 4;
+}
+
 // ******************************** YUVJ422P -> ********************************
 
 static inline void transfer_YUVJ422P_to_RGB888(unsigned char *(*output), 
@@ -1398,6 +1592,17 @@ static inline void transfer_YUVJ422P_to_RGB888(unsigned char *(*output),
 	(*output) += 3;
 }
 
+static inline void transfer_YUVJ422P_to_RGBA8888(unsigned char *(*output), 
+	unsigned char *input_y,
+	unsigned char *input_u,
+	unsigned char *input_v)
+{
+        int i_tmp;
+	YUVJ_8_TO_RGB_24(*input_y, *input_u, *input_v, (*output)[0], (*output)[1], (*output)[2])
+        (*output)[3] = 0xff;
+	(*output) += 4;
+}
+
 static inline void transfer_YUVJ422P_to_YUV422(unsigned char *(*output), 
 	unsigned char *input_y,
 	unsigned char *input_u,
@@ -1444,6 +1649,17 @@ static inline void transfer_YUVJ420P_to_RGB888(unsigned char *(*output),
 	(*output) += 3;
 }
 
+static inline void transfer_YUVJ420P_to_RGBA8888(unsigned char *(*output), 
+	unsigned char *input_y,
+	unsigned char *input_u,
+	unsigned char *input_v)
+{
+        int i_tmp;
+	YUVJ_8_TO_RGB_24(*input_y, *input_u, *input_v, (*output)[0], (*output)[1], (*output)[2])
+        (*output)[3] = 0xff;
+	(*output) += 4;
+}
+
 
 // ******************************** YUV422 -> *********************************
 
