@@ -41,6 +41,18 @@
 
 int ffmpeg_num_audio_codecs = -1;
 int ffmpeg_num_video_codecs = -1;
+
+#if LIBAVCODEC_VERSION_MAJOR >= 53
+#define CodecType AVMediaType
+#define CODEC_TYPE_UNKNOWN    AVMEDIA_TYPE_UNKNOWN
+#define CODEC_TYPE_VIDEO      AVMEDIA_TYPE_VIDEO
+#define CODEC_TYPE_AUDIO      AVMEDIA_TYPE_AUDIO
+#define CODEC_TYPE_DATA       AVMEDIA_TYPE_DATA
+#define CODEC_TYPE_SUBTITLE   AVMEDIA_TYPE_SUBTITLE
+#define CODEC_TYPE_ATTACHMENT AVMEDIA_TYPE_ATTACHMENT
+#define CODEC_TYPE_NB         AVMEDIA_TYPE_NB
+#endif
+
   
 #define ENCODE_PARAM_AUDIO \
   { \
@@ -799,8 +811,9 @@ struct CODECIDMAP codecidmap_v[] =
       .name = TRS("FFMPEG dnxhd"),
             .fourccs = { "AVdn", (char *)0 },
       .wav_ids = { LQT_WAV_ID_NONE },
-      .compatibility_flags = 0,
-      .do_encode = 1
+      .compatibility_flags = LQT_FILE_QT,
+      .do_encode = 1,
+      .encoding_colormodels = (int[]){ BC_YUV422P, BC_YUVJ422P, LQT_COLORMODEL_NONE }
     },
 #endif
     {
