@@ -203,6 +203,14 @@
 						input_v + (v_in_offset)); \
 					TRANSFER_FRAME_TAIL \
 					break; \
+				case BC_RGBA8888:      \
+					TRANSFER_YUV411P_IN_HEAD \
+					transfer_YUV411P_to_RGBA8888((output), \
+						input_y + (y_in_offset), \
+						input_u + (u_in_offset), \
+						input_v + (v_in_offset)); \
+					TRANSFER_FRAME_TAIL \
+					break; \
 			} \
 			break; \
  \
@@ -217,6 +225,14 @@
 						input_v + (v_in_offset)); \
 					TRANSFER_FRAME_TAIL \
 					break; \
+				case BC_RGBA8888:      \
+					TRANSFER_YUV444P_IN_HEAD \
+					transfer_YUVJ444P_to_RGBA8888((output), \
+						input_y + (y_in_offset), \
+						input_u + (u_in_offset), \
+						input_v + (v_in_offset)); \
+					TRANSFER_FRAME_TAIL \
+					break; \
 				case BC_YUVJ444P:      \
 					for(i = 0; i < out_h; i++) \
 					{ \
@@ -252,6 +268,14 @@
 						input_v + (v_in_offset)); \
 					TRANSFER_FRAME_TAIL \
 					break; \
+				case BC_RGBA8888:      \
+					TRANSFER_YUV422P_IN_HEAD \
+					transfer_YUVJ422P_to_RGBA8888((output), \
+						input_y + (y_in_offset), \
+						input_u + (u_in_offset), \
+						input_v + (v_in_offset)); \
+					TRANSFER_FRAME_TAIL \
+					break; \
 				case BC_YUVJ422P: \
 					for(i = 0; i < out_h; i++) \
 					{ \
@@ -338,6 +362,14 @@
 						input_v + (v_in_offset)); \
 					TRANSFER_FRAME_TAIL \
 					break; \
+				case BC_RGBA8888:      \
+					TRANSFER_YUV420P_IN_HEAD \
+					transfer_YUVJ420P_to_RGBA8888((output), \
+						input_y + (y_in_offset), \
+						input_u + (u_in_offset), \
+						input_v + (v_in_offset)); \
+					TRANSFER_FRAME_TAIL \
+					break; \
 				case BC_YUVJ420P: \
 					for(i = 0; i < out_h; i++) \
 					{ \
@@ -544,6 +576,14 @@
 						input_v + (v_in_offset)); \
 					TRANSFER_FRAME_TAIL \
 					break; \
+				case BC_RGBA8888:      \
+					TRANSFER_YUV422P16_IN_HEAD \
+					transfer_YUV422P16_to_RGBA8888((output), \
+						input_y + (y_in_offset), \
+						input_u + (u_in_offset), \
+						input_v + (v_in_offset)); \
+					TRANSFER_FRAME_TAIL \
+					break; \
 				case BC_RGB161616:      \
 					TRANSFER_YUV422P16_IN_HEAD_16 \
 					transfer_YUV422P16_to_RGB161616((output), \
@@ -607,6 +647,14 @@
 						input_v + (v_in_offset)); \
 					TRANSFER_FRAME_TAIL \
 					break; \
+				case BC_RGBA8888:      \
+					TRANSFER_YUV444P16_IN_HEAD \
+					transfer_YUV444P16_to_RGBA8888((output), \
+						input_y + (y_in_offset), \
+						input_u + (u_in_offset), \
+						input_v + (v_in_offset)); \
+					TRANSFER_FRAME_TAIL \
+					break; \
 				case BC_RGB161616:      \
 					TRANSFER_YUV444P16_IN_HEAD_16 \
 					transfer_YUV444P16_to_RGB161616((output), \
